import{S as d}from"./Sidebar.30d791c2.js";import{N as m}from"./Navbar.df60a519.js";import{F as l,G as p,H as u}from"./icons.35c960d1.js";import{d as _,K as b,b as f,c as g,e as t,z as r,x as v,F as y,J as z,a as w,q as I}from"./registerWidgets.8e2e133d.js";import{a as h}from"./asyncComputed.a6090ca2.js";import"./gateway.57276d9e.js";import{O}from"./organization.7a481b36.js";import"./Tooltip.4245b6a5.js";import"./logo.084e5d7c.js";import"./passwordlessManager.cb9f88a0.js";import"./activeRecord.eba5e90d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="623dc643-6a16-4d14-a8c6-5cd1bc0c72e6",e._sentryDebugIdIdentifier="sentry-dbid-623dc643-6a16-4d14-a8c6-5cd1bc0c72e6")}catch{}})();const x={class:"organization"},k=_({__name:"Organization",setup(e){const n=z().params.organizationId,{result:o}=h(()=>O.get(n)),s=b(()=>o.value?[{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:p,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(B,D)=>{const c=w("router-view");return f(),g(y,null,[t(m,{breadcrumb:r(s)},null,8,["breadcrumb"]),v("div",x,[t(d,{class:"sidebar",sections:r(i)},null,8,["sections"]),t(c)])],64)}}});const J=I(k,[["__scopeId","data-v-7eef90b7"]]);export{J as default};
//# sourceMappingURL=Organization.e6a35773.js.map
