import{q as t,b as s,c}from"./registerWidgets.f021c1a4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="1b9aa717-d0b6-4859-9c1d-43c07ebcc330",e._sentryDebugIdIdentifier="sentry-dbid-1b9aa717-d0b6-4859-9c1d-43c07ebcc330")}catch{}})();const o={},r={class:"organization-settings"};function a(e,n){return s(),c("div",r,"Organization settings")}const f=t(o,[["render",a]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.c3556dea.js.map
