import{L as a}from"./lottie.84b3db69.js";import{d as t,r as d,o as r,b as s,c as i,x as c,B as _,q as l}from"./registerWidgets.fce18b61.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="b7d696bb-eadd-41d5-9a6d-168b15bc5eb0",n._sentryDebugIdIdentifier="sentry-dbid-b7d696bb-eadd-41d5-9a6d-168b15bc5eb0")}catch{}})();const u={class:"container"},b=t({__name:"LoadingIndicator",setup(n){const e=d(null);return r(()=>{!e.value||a.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(o,f)=>(s(),i("div",u,[c("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(o.$slots,"default",{},void 0,!0)]))}});const g=l(b,[["__scopeId","data-v-c30401d8"]]);export{g as L};
//# sourceMappingURL=LoadingIndicator.b25e3053.js.map
