import{d as u,K as m,b as _,t as f,w as b,z as d,J as y,O as g,Q as h,x as i,S as n,q as w}from"./registerWidgets.eddc32f4.js";import{a as I}from"./asyncComputed.562c187e.js";import"./gateway.7d65591c.js";import{B as x}from"./build.501050a0.js";import{C as v}from"./CrudView.4dc213ee.js";import"./passwordlessManager.8b97cbcd.js";import"./activeRecord.ed4e0294.js";import"./DropdownMenu.07e05b99.js";import"./Modal.bb1eb9c5.js";import"./LoadingIndicator.f662ca6a.js";import"./lottie.6d443700.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="5262845b-a601-46ad-a0e2-54975f2b83fc",e._sentryDebugIdIdentifier="sentry-dbid-5262845b-a601-46ad-a0e2-54975f2b83fc")}catch{}})();const B=e=>(g("data-v-1b7a68a8"),e=e(),h(),e),C=B(()=>i("div",{class:"instructions"},[n(" Get started with the local editor in seconds: "),i("pre",null,`    $ pip install abstra --upgrade
    $ abstra serve ./your-project-directory
    `),n(" And you're done! Explore the local editor and start building apps. ")],-1)),S=u({__name:"Builds",setup(e){const r=y().params.projectId,{loading:c,result:p}=I(()=>x.list(r)),l=m(()=>{var o,s;return{columns:[{name:"Id"},{name:"Creation date"},{name:"Status"}],rows:(s=(o=p.value)==null?void 0:o.map(t=>({key:t.id,cells:[{text:t.id,classes:["title","centered"]},{text:t.createdAt.toLocaleString(),classes:[]},{text:t.status,classes:["centered"]}]})))!=null?s:[]}});return(o,s)=>(_(),f(v,{"entity-name":"build",loading:d(c),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:d(l)},{"empty-description":b(()=>[C]),_:1},8,["loading","table"]))}});const J=w(S,[["__scopeId","data-v-1b7a68a8"]]);export{J as default};
//# sourceMappingURL=Builds.fbe847f1.js.map
