import{d,r as i,o as l,a3 as f,b as u,c,N as y,ad as b}from"./registerWidgets.8e2e133d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="f1166035-3423-4da6-9389-0cb125ea8f72",e._sentryDebugIdIdentifier="sentry-dbid-f1166035-3423-4da6-9389-0cb125ea8f72")}catch{}})();const g=d({__name:"ActionButton",props:{action:null},emits:["next"],setup(e,{emit:n}){const o=e,s=i(null);l(()=>{s.value&&o.action.setElement(s.value),f.addAction(o.action)});const a=()=>n("next");return(m,t)=>(u(),c("button",{ref_key:"element",ref:s,class:"next-button",onClick:t[0]||(t[0]=r=>a()),onKeydown:t[1]||(t[1]=b(r=>a(),["enter"]))},y(e.action.name),545))}});export{g as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.20bd37d2.js.map
