import{x as a}from"./icons.8b9604eb.js";import{d as c,a as r,b as d,c as i,e as _,z as l,S as f,q as u}from"./registerWidgets.1590c05e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="729e4fd6-1ad5-4626-89ec-29796c665cfc",e._sentryDebugIdIdentifier="sentry-dbid-729e4fd6-1ad5-4626-89ec-29796c665cfc")}catch{}})();const p=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=r("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:l(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),f(" Editor ")])}}});const w=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.1759d1e9.js.map
