import{d as P,v as x,r as F,K as R,b as n,c as i,z as e,t as B,e as d,x as I,H as q,J as E,q as D}from"./registerWidgets.80830a62.js";import{L}from"./CircularLoading.dfc9e798.js";import{E as C}from"./Error.e8920d2f.js";import{F as N,R as H}from"./broker.6a85f534.js";import{B as M}from"./BackButton.ffb59a51.js";import{a as _}from"./asyncComputed.7fd138fd.js";import{F as V}from"./forms.9a920c96.js";import{W}from"./workspaces.f05f8c3f.js";import"./lottie.ab5349ef.js";import"./passwordlessManager.65c1d475.js";import"./icons.96376736.js";import"./ActionButton.vue_vue_type_script_setup_true_lang.f332c731.js";import"./Passwordless.e6779d6e.js";import"./executeJs.74f241ca.js";import"./PlayerNavbar.1f5ef7b9.js";import"./index.9089c8c2.js";import"./WidgetsFrame.fba80f3e.js";import"./colors.8b04d8aa.js";import"./Modal.75286ba0.js";import"./log.3ccd8497.js";import"./activeRecord.dd1973bd.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[t]="b5db19ed-b5e0-4e96-a378-59c35f156e0c",s._sentryDebugIdIdentifier="sentry-dbid-b5db19ed-b5e0-4e96-a378-59c35f156e0c")}catch{}})();const z={class:"page"},J={key:1,class:"error"},K={key:2,style:{width:"100%",height:"100%",display:"flex"}},S={style:{width:"100%",height:"100%",display:"flex"}},U=P({__name:"FormPreview",setup(s){const t=q(),r=E(),a=x({started:!1}),m=F(null),{loading:h,result:c,error:u,refetch:p}=_(()=>V.get(r.params.formPath)),{result:f}=_(()=>W.get()),y=R(()=>H.create({isLocal:!1,formPath:r.params.formPath,isPreview:!0})),v=async()=>{var o;if(!a.started){(o=m.value)==null||o.run();return}a.started=!1},b=({path:o,type:l})=>{l==="dash"?t.push({name:"dashPreview",params:{dashPath:o},query:r.query}):(t.push({name:"form-preview",params:{formPath:o},query:r.query}),p())},g=()=>{t.push(`/_editor/form/${encodeURIComponent(r.params.formPath)}`)},w=()=>{a.started=!0},k=()=>{a.started=!1};return(o,l)=>(n(),i("div",z,[e(h)||!e(c)||!e(f)?(n(),B(L,{key:0})):e(u)?(n(),i("div",J,[d(C,{error:e(u),onReload:e(p)},null,8,["error","onReload"])])):(n(),i("main",K,[I("div",S,[d(N,{ref_key:"runner",ref:m,form:e(c).makeRunnerData(e(f)),params:e(r).query,"is-preview":!0,"enable-auto-focus":!0,broker:e(y),style:{height:"unset",flex:1,overflow:"hidden"},onNavigate:b,onLogout:v,onExit:k,onStart:w},null,8,["form","params","broker"]),d(M,{onExitFullscreenPreview:g})])]))]))}});const ue=D(U,[["__scopeId","data-v-f7c2ba13"]]);export{ue as default};
//# sourceMappingURL=FormPreview.9319c1f0.js.map
