import{M as a}from"./Modal.add412a5.js";import{d as r,v as c,r as _,b as d,c as l,e as n,w as f,F as i,a as m,x as u,q as p}from"./registerWidgets.9f96e537.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="948f67a7-0e0c-422a-8b64-711a623c0833",e._sentryDebugIdIdentifier="sentry-dbid-948f67a7-0e0c-422a-8b64-711a623c0833")}catch{}})();const b=["src"],y=r({__name:"Home",setup(e){const o=c({onboardingForm:""}),t=_(null);return(g,v)=>{const s=m("router-view");return d(),l(i,null,[n(s,{class:"router"}),n(a,{ref_key:"modal",ref:t},{content:f(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,b)]),_:1},512)],64)}}});const I=p(y,[["__scopeId","data-v-8c8bc27e"]]);export{I as default};
//# sourceMappingURL=Home.d6ef7e71.js.map
