import{d as _,r as i,K as y,b as m,c as v,B,x as c,N as g,A as k,z as $,q as b}from"./registerWidgets.81004098.js";const h={class:"text"},N=_({__name:"Tooltip",props:{text:{type:String,required:!0},left:{type:Number},top:{type:Number},fixed:{type:Boolean,default:!1}},setup(o){const e=o,s=i(Date.now()),u=()=>{s.value=Date.now()},n=i(null),f=()=>{var r,l,p;const t=(r=n.value)==null?void 0:r.getBoundingClientRect();if(!t)return{};const{x:a,y:x}=t;return s.value,{position:"fixed",top:`${x+((l=e.top)!=null?l:0)}px`,left:`${a+((p=e.left)!=null?p:0)}px`}},d=y(()=>{var t;return e.fixed?f():{left:`${(t=e.left)!=null?t:-14}px`,...e.top?{top:`${e.top}px`}:{}}});return(t,a)=>(m(),v("div",{ref_key:"tooltipBox",ref:n,class:"tooltip-box",onMouseenter:u},[B(t.$slots,"default",{},void 0,!0),c("div",{class:"tooltip",style:k($(d))},[c("span",h,g(o.text),1)],4)],544))}});const T=b(N,[["__scopeId","data-v-74636348"]]);export{T};
//# sourceMappingURL=Tooltip.879659d1.js.map
