import{L as o}from"./lottie.1c3b7cde.js";import{d as t,r,o as d,b as s,c as i,x as c,B as _,q as l}from"./registerWidgets.726232df.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="5ce39149-a827-426f-ad5c-d7ea733c0e6f",n._sentryDebugIdIdentifier="sentry-dbid-5ce39149-a827-426f-ad5c-d7ea733c0e6f")}catch{}})();const u={class:"container"},f=t({__name:"LoadingIndicator",setup(n){const e=r(null);return d(()=>{!e.value||o.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(a,p)=>(s(),i("div",u,[c("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(a.$slots,"default",{},void 0,!0)]))}});const m=l(f,[["__scopeId","data-v-c30401d8"]]);export{m as L};
//# sourceMappingURL=LoadingIndicator.758ab81e.js.map
