import{q as t,b as s,c as f}from"./registerWidgets.1590c05e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="53ff187a-e154-4db9-a4ff-83066f446864",e._sentryDebugIdIdentifier="sentry-dbid-53ff187a-e154-4db9-a4ff-83066f446864")}catch{}})();const o={},r={class:"organization-settings"};function a(e,n){return s(),f("div",r,"Organization settings")}const c=t(o,[["render",a]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.89cb3a1c.js.map
